// --- [ dog_main.c ] ---------------------------------------------------------

#include <avr/interrupt.h>
#include <avr/io.h>
#include <avr/pgmspace.h>
#include <stdlib.h>
#include <string.h>
#include <util/delay.h>
#include "global.h"
#include "dog128x64.h"
#include "dog_gfx.h"
#include "dog_dia.h"


void delay_10ms(uint8_t t);
char msg[10];



// ----------------------------------------------------------------------------
int main (void)

{
uint8_t x,i,j;
int8_t step;
uint16_t ii;

DOG_init();
DOG_cls();

DOG_dimm_led(64);

// --- TEXT-FONT DEMO -------------------------------------------------
#if DEMO == TEXT_FONT_DEMO

DOG_txt_pos(0,0);
DOG_print_s("LUFTDRUCK");
DOG_txt_pos(0,1);
DOG_print_s("[mbar]");

DOG_set_font(FONT_BIG);
DOG_txt_pos(10, 1);
DOG_print_s("1234");
DOG_font_big_point();
DOG_print_s("2");

DOG_txt_pos(1, 5);
DOG_print_s("1234");
DOG_print_s("ABC");
DOG_print_s("ab");

DOG_set_font(FONT_NORMAL);
DOG_txt_pos(1, 7);
DOG_print_s("1234");
DOG_print_s("ABC");
DOG_print_s("ab");

delay_10ms(250);
DOG_cls();


j = 'A';
for(i = 0; i < 20; i++)
	{
	DOG_txt_pos(i, i/3);			
	DOG_print_c(j++);
	}

delay_10ms(250);
DOG_cls();

for (i = 0; i < 17; i++)
   {
      DOG_txt_pos(i, 0);
      DOG_print_s(" PING");
      delay_10ms(25);
   }

for (i = 20; i > 0; i--)
   {
      DOG_txt_pos(i, 1);
      DOG_print_s("PONG ");
      delay_10ms(25);
   }

for (i = 0; i < (MAX_COL - DISPLAY_OFFSET - 32); i++)
   {
      DOG_goto_xy(i, 2);
      DOG_print_s(" PING");
      delay_10ms(25);
   }

for (i = (MAX_COL - DISPLAY_OFFSET - 28); i > 7; i--)
   {
      DOG_goto_xy(i, 3);
      DOG_print_s("PONG ");
      delay_10ms(25);
   }

DOG_set_font(FONT_BIG);
DOG_txt_pos(7, 7);
DOG_print_s("ENDE");

// --- BARGRAPH DEMO --------------------------------------------------
#elif DEMO == BARGRAPH_DEMO

DOG_txt_pos(0, 0);
DOG_print_s("BARGRAPH-DEMO");

DOG_h_bargraph(2, 0);
DOG_h_bargraph(3, 1);
DOG_h_bargraph(4, 99);
DOG_h_bargraph(5, 100);

step = 1;
while(1)
	{
	DOG_h_bargraph(6,i);
	DOG_h_bargraph(7,100 - i);
	_delay_ms(100);
	i += step;
	if (i > 99) step = -1;
	else if (i == 0) step = 1;
	}


// --- FLOATENDES DIAGRAMM DEMO ------------------------------------
#elif DEMO == DIAGRAMM_FLOAT_DEMO

#define START 10100
#define END   10400

uint16_t v = (START + (END - START) / 2);
step = 1;
i = 0;

fill_array(v);

while(1)
   {
   DOG_dia_float(v);
	i++;
	if ((i % 3) == 0)
	{
		v += step;
		if (v > END - 1) step = -1;
		else if (v < START + 1) step = 1;
	}

   _delay_ms(500);
 }

// --- DIAGRAMM FIXED DEMO -------------------------------------------
#elif DEMO == DIAGRAMM_FIXED_DEMO

#define MIN 480
#define MAX 520
ii = MIN + (MAX - MIN) / 2;
i = 0;
step = 1;

fill_array(ii);

while(1)
	{
	DOG_dia_fixed(ii);
	i++;
	if ((i % 3) == 0)								// nur jede dritte Runde den Wert ndern
		{
		ii += step;
		if (ii > MAX - 1) step = -1;
		else if (ii < MIN + 1) step = 1;
		}
	_delay_ms(500);
	}

// --- GRAPHIK DEMO ---------------------------------------------------
#elif DEMO == GRAPHIK_DEMO

DOG_txt_pos(0, 0);
DOG_print_s("GRAFIKDEMO");

DOG_box(0,0,63,63, SET_PIX);
DOG_write_gfx();

DOG_txt_pos(13, 3);
DOG_print_s("GRAFIK");
DOG_txt_pos(13, 4);
DOG_print_s("WINDOW");

delay_10ms(255);

DOG_txt_pos(0, 2);
DOG_print_s("LINE");
DOG_txt_pos(0, 3);
DOG_print_s("SET_PIX");

for(i = 0; i < 64; i++)
	{
	delay_10ms(20);
	DOG_line(i, 0, 63 - i, 63, SET_PIX);
	DOG_write_gfx();
	}

delay_10ms(20);
DOG_txt_pos(0, 3);
DOG_print_s("XOR_PIX");

for(i = 0; i < 64; i++)
	{
	delay_10ms(20);
	DOG_line(0, i, 63, 63 - i, XOR_PIX);
	DOG_write_gfx();
	}

delay_10ms(200);
DOG_clear_gfx();

DOG_txt_pos(0, 2);
DOG_print_s("VLINE");
DOG_txt_pos(0, 3);
DOG_print_s("SET_PIX");

for(i = 0; i < 64; i +=2)
	{
	delay_10ms(20);
	DOG_vline(i, 0, 63, SET_PIX);
	DOG_write_gfx();
	}

DOG_txt_pos(0, 2);
DOG_print_s("HLINE");
DOG_txt_pos(0, 3);
DOG_print_s("CLR_PIX");


for(i = 0; i < 64; i +=2)
	{
	delay_10ms(20);
	DOG_hline(0, 63, i, CLR_PIX);
	DOG_write_gfx();
	}

DOG_txt_pos(0, 3);
DOG_print_s("SET_PIX");

for(i = 0; i < 64; i++)
	{
	delay_10ms(20);
	DOG_hline(0, 63, i, SET_PIX);
	DOG_write_gfx();
	}

DOG_txt_pos(0, 2);
DOG_print_s("BOX  ");
DOG_txt_pos(0, 3);
DOG_print_s("XOR_PIX");

for(i = 0; i < 32; i+= 2)
	{
	delay_10ms(20);
	DOG_box(i, i, 63 - i, 63- i, XOR_PIX);
	DOG_write_gfx();
	}

DOG_clear_gfx();

DOG_line(10,0,53,63,SET_PIX);  // eine schrge Linie

for(i = 1; i < 59; i++)			// Text im Grafikmodus
   {
   DOG_set_gfx_position(i, i);
   DOG_print_gc(0, XOR_PIX);   // diese Zeile schreibt den Text
	DOG_set_gfx_position(62 - i,32);
	DOG_print_gc(1, XOR_PIX);
	DOG_write_gfx();

//  DOG_clear_gfx();          // lscht den gesamten Bildschirmspeicher
// berschreibt nur den gerade geschriebenen Text
// ggf. vorhandene andere Grafikelemente werden dabei nicht gelscht !!
   DOG_set_gfx_position(i, i);
   DOG_print_gc(0, XOR_PIX); 	// diese Zeile lscht den Text wieder
 	DOG_set_gfx_position(62 - i,32);
	DOG_print_gc(1, XOR_PIX);   // diese Zeile lscht den Text wieder
	delay_10ms(30);
   }

DOG_txt_pos(0, 7);
DOG_print_s("ENDE");

  // --- GRAPHIK DEMO ---------------------------------------------------
#endif

while(1);

}


// ----------------------------------------------------------------------------
void delay_10ms(uint8_t t)
{
while(t--) _delay_ms(10);
}

// --- [ eof ] ----------------------------------------------------------------
